Scaffolding
-----------
Following modules provide templates for getting started with Invenio:

- `cookiecutter-invenio-instance <https://github.com/inveniosoftware/cookiecutter-invenio-instance>`_
    - Template for new Invenio instances.
- `cookiecutter-invenio-module <https://github.com/inveniosoftware/cookiecutter-invenio-module>`_
    - Template for a reusable Invenio module.
- `cookiecutter-invenio-rdm <https://github.com/inveniosoftware/cookiecutter-invenio-rdm>`_
    - Cookiecutter template for a new Invenio RDM instance.

Discontinued:

- `cookiecutter-invenio-datamodel <https://github.com/inveniosoftware/cookiecutter-invenio-datamodel>`_
    - Template for new data models.
